# MKTMP

MKTMP is a command-line tool for creating temporary directories along with symbolic links to them — enabling centralized, consistent management of ephemeral files.

## Setup

Add your user to the "Create symbolic links" user right in Windows to avoid permission issues when creating symbolic links.

```
Security Settings > Local Policies > User Rights Assignment > Create symbolic links
安全设置 > 本地策略 > 用户权限分配 > 创建符号链接
```